# Peridio EVK CLI

This is a command-line tool for initializing the Peridio EVK for use with [Peridio Cloud](https://www.peridio.com)

## Installation

```bash
pip install -e .
```

## Usage

For information on configuration and usage, see the [Peridio EVK Docs](https://docs.peridio.com/evk)
